**********************************
The sherpa.astro.instrument module
**********************************

.. currentmodule:: sherpa.astro.instrument

.. automodule:: sherpa.astro.instrument

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      ARF1D
      PileupResponse1D
      RMF1D
      Response1D
      MultipleResponse1D
      PSFModel
      ARFModel
      ARFModelNoPHA
      ARFModelPHA
      RMFModel
      RMFModelNoPHA
      RMFModelPHA
      RSPModel
      RSPModelNoPHA
      RSPModelPHA
      MultiResponseSumModel
      PileupRMFModel
      RMFMatrix
   
   .. rubric:: Functions
               
   .. autosummary::
      :toctree: api

      create_arf
      create_delta_rmf
      create_non_delta_rmf
      rmf_to_matrix
      rmf_to_image

Class Inheritance Diagram
=========================

.. inheritance-diagram:: ARF1D PileupResponse1D RMF1D Response1D MultipleResponse1D PSFModel ARFModel ARFModelNoPHA ARFModelPHA RMFModel RMFModelNoPHA RMFModelPHA RSPModel RSPModelNoPHA RSPModelPHA MultiResponseSumModel PileupRMFModel RMFMatrix

